@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.8.0"
+__version__ = "3.0.0"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -351,6 +351,7 @@ class MetaModelFactory(object):
         'reference': ReferenceDescriptor,
         'date': DateDescriptor,
         'datetime': DateTimeDescriptor,
+        'timestamp': DateTimeDescriptor,
         'time': TimeDescriptor,
         'dict': DictDescriptor,
         'many2one': Many2OneDescriptor,
@@ -630,7 +631,8 @@ class Model(object):
     def __cmp__(self, other):
         'Compare with other'
         if isinstance(other, Model):
-            return cmp(self.id, other.id)
+            return cmp((self.__class__.__name__, self.id),
+                (other.__class__.__name__, other.id))
         if isinstance(other, (bool, NoneType)):
             return 1
         raise NotImplementedError
